@@ -86,13 +86,46 @@ Currency *cur;
 
 	cur = da_cur_get(kcur);
 	if(cur == NULL || cur->rate == 0.0)
-		return 0;
+		return 0.0;
 
 	newvalue = value / cur->rate;
 	return hb_amount_round(newvalue, cur->frac_digits);
 }
 
 
+/* we have rate versus base curency */
+gdouble hb_amount_convert(gdouble value, guint32 skcur, guint32 dkcur)
+{
+gdouble newvalue;
+Currency *cur;
+
+	if( skcur == dkcur )
+		return value;
+
+	/* we can't convert if no base currency as src or dst */ 
+	if( skcur != GLOBALS->kcur && dkcur != GLOBALS->kcur )
+		return 0.0;
+
+	if(dkcur == GLOBALS->kcur)
+	{
+		cur = da_cur_get(skcur);
+		if(cur == NULL || cur->rate == 0.0)
+			return 0.0;
+		newvalue = value / cur->rate;
+	}
+
+	if(skcur == GLOBALS->kcur)
+	{
+		cur = da_cur_get(dkcur);
+		if(cur == NULL || cur->rate == 0.0)
+			return 0.0;
+		newvalue = value * cur->rate;
+	}
+
+	return hb_amount_round(newvalue, cur->frac_digits);
+}
+
+
 gboolean hb_amount_type_match(gdouble amount, gint type)
 {
 gboolean retval = TRUE;
@@ -106,6 +139,20 @@ gboolean retval = TRUE;
 }
 
 
+gboolean hb_amount_between(gdouble val, gdouble min, gdouble max)
+{
+gboolean retval = FALSE;
+
+	if(val > 0.0)
+		retval = (val >= min && val <= max);
+	else
+	if(val < 0.0)
+		retval = (val <= min && val >= max);
+
+	return retval;
+}
+
+
 gint hb_amount_compare(gdouble val1, gdouble val2)
 {
 gint retval = 0;
@@ -290,7 +337,6 @@ gdouble monval;
 		g_ascii_formatd(formatd_buf, outlen, cur->format, monval);
 		hb_str_formatd(outstr, outlen, formatd_buf, cur, TRUE);
 	}
-
 }
 
 
@@ -348,6 +394,30 @@ gdouble monval;
 }
 
 
+void hb_strlifeenergy(gchar *outstr, gint outlen, gdouble value, guint32 kcur, gboolean minor)
+{
+gchar buf_energy[16];
+gdouble monval;
+gdouble intval, fracval;
+gshort h, m;
+
+	//first print monetary
+	hb_strfmon(outstr, outlen, value, kcur, minor);
+
+	if( !hb_amount_equal(GLOBALS->lifen_earnbyh, 0.0) && value < 0.0)
+	{
+		monval = hb_amount_base(value, kcur);
+		fracval = modf(ABS(monval) / GLOBALS->lifen_earnbyh, &intval); 
+		h = (gint)intval;
+		m = (gint)(fracval*60);
+		if( (gint)(m / 60) > 30 ) m++;
+
+		g_sprintf(buf_energy, " (%dh%02dm)", h, m);
+		strcat(outstr, buf_energy);
+	}
+}
+
+
 gchar *get_normal_color_amount(gdouble value)
 {
 gchar *color = NULL;
@@ -1244,13 +1314,12 @@ gchar buffer1[128];
 GDate *date;
 
 	date = g_date_new_julian(jdate);
-	g_date_strftime (buffer1, 128-1, "%x", date);
+	g_date_strftime (buffer1, 128-1, "%a %x", date);
 	g_date_free(date);
-	g_print(" - %s %s\n", label != NULL ? label:"date is", buffer1);
+	g_print("%s %d - '%s'\n", label != NULL ? label:"date is", jdate, buffer1);
 }
 
 
-
 /*
 ** parse a string an retrieve an iso date (dd-mm-yy(yy) or dd/mm/yy(yy))
 **
